@@ -1,7 +1,6 @@
 package Lingua::EN::GivenNames::Database::Import;
 
-use feature qw/say unicode_strings/;
-use open qw(:std :utf8);
+use feature 'say';
 use parent 'Lingua::EN::GivenNames::Database';
 use strict;
 use warnings;
@@ -13,19 +12,26 @@ use DBI;
 
 use File::Spec;
 
-use Hash::FieldHash ':all';
-
 use HTML::TreeBuilder;
 
-use IO::File;
+use Moo;
 
 use Text::CSV;
+use Text::CSV::Slurp;
 
 use Unicode::CaseFold;  # For fc().
 
-fieldhash my %page_number => 'page_number';
+use Types::Standard qw/Int/;
 
-our $VERSION = '1.00';
+has page_number =>
+(
+	default  => sub{return 1},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+our $VERSION = '1.02';
 
 # ----------------------------------------------
 
@@ -130,17 +136,6 @@ sub generate_derivation
 
 } # End of generate_derivation.
 
-# -----------------------------------------------
-
-sub _init
-{
-	my($self, $arg)    = @_;
-	$$arg{page_number} ||= 1; # Caller can set.
-
-	return $self -> SUPER::_init($arg);
-
-} # End of _init.
-
 # ----------------------------------------------
 
 sub import_derivations
@@ -508,27 +503,13 @@ EOS
 
 } # End of parse_derivations.
 
-# -----------------------------------------------
-
-sub read_csv_file
-{
-	my($self, $file_name) = @_;
-	my($csv) = Text::CSV -> new({allow_whitespace => 1, binary => 1});
-	my($io)  = IO::File -> new($file_name, 'r');
-
-	$csv -> column_names($csv -> getline($io) );
-
-	return $csv -> getline_hr_all($io);
-
-} # End of read_csv_file.
-
 # ----------------------------------------------
 
 sub read_derivations
 {
 	my($self)      = @_;
 	my($file_name) = File::Spec -> catfile($self -> data_dir, 'derivations.csv');
-	my($line)      = $self -> read_csv_file($file_name);
+	my($line)      = Text::CSV::Slurp -> new -> load(file => $file_name, allow_whitespace => 1);
 	my($count)     = 0;
 
 	$self -> log(debug => "File: $file_name. Derivation count: " . scalar @$line);
@@ -754,12 +735,6 @@ Clearly, this is where most of the work takes place.
 
 Returns 0 to indicate success.
 
-=head2 read_csv_file($file_name)
-
-Reads the given $file_name and returns an arrayref of hashrefs.
-
-The input file must have column headings. These become keys in the hashrefs.
-
 =head2 read_derivations()
 
 This method is called by sub import_derivations(). It reads and validates data/derivations.raw.
